#include <QAction>
#include <QApplication>
#include <QDockWidget>
#include <QMainWindow>
#include <QMenu>
#include <QMenuBar>
#include <QPlainTextEdit>
#include <QToolBar>

#include <QDebug>

static QString title()
{
    QString r = QT_VERSION_STR;
#if QT_VERSION >= 0x050000
    r += QLatin1Char(' ') + QGuiApplication::platformName();
#endif
    return r;
}

static QDockWidget *createDockWidget(QString t)
{
    auto result = new QDockWidget(t);
    result->setObjectName(t);
    result->setWidget(new QPlainTextEdit(t));
    return result;
}

class MainWindow : public QMainWindow
{
public:
    MainWindow();

private:
};

MainWindow::MainWindow()
{
    QMenu *fMenu = menuBar()->addMenu("File");
    QAction *qa = fMenu->addAction("Quit");
    qa->setShortcut(Qt::CTRL + Qt::Key_Q);
    connect(qa, SIGNAL(triggered()), qApp, SLOT(quit()));
    auto tb = new QToolBar;
    addToolBar(Qt::TopToolBarArea, tb);
    tb->addAction(qa);

    setDockOptions(dockOptions() | GroupedDragging);

    setTabPosition(Qt::LeftDockWidgetArea, QTabWidget::West);
    addDockWidget(Qt::LeftDockWidgetArea, createDockWidget("Left1"));
    addDockWidget(Qt::LeftDockWidgetArea, createDockWidget("Left2"));

    setTabPosition(Qt::TopDockWidgetArea, QTabWidget::North);
    addDockWidget(Qt::TopDockWidgetArea, createDockWidget("Top1"));
    addDockWidget(Qt::TopDockWidgetArea, createDockWidget("Top2"));

    setTabPosition(Qt::RightDockWidgetArea, QTabWidget::East);
    addDockWidget(Qt::RightDockWidgetArea, createDockWidget("Right1"));
    addDockWidget(Qt::RightDockWidgetArea, createDockWidget("Right2"));

    setTabPosition(Qt::BottomDockWidgetArea, QTabWidget::South);
    addDockWidget(Qt::BottomDockWidgetArea, createDockWidget("Bottom1"));
    addDockWidget(Qt::BottomDockWidgetArea, createDockWidget("Bottom2"));

    auto pe = new QPlainTextEdit("Central");
    setCentralWidget(pe);
}

int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QStringList args = a.arguments();
    args.pop_front();
    auto t = title();
    qDebug() << t << args;
    MainWindow w;
    w.setWindowTitle(t);
    w.show();

    return a.exec();
}

